//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[minkan](minkan.md)

# minkan

[common]\
val [minkan](minkan.md): [ShantenWithoutGot](../-shanten-without-got/index.md)?

明杠后的向听信息（若无法明杠则为null）
